pub struct ConnInfo<T>where
T: Trackable,{
pub linfo: LayerInfo,
pub cdata: ConnData,
pub layers: [Layer; 1],
pub tracked: T,
}Expand description
Per-connection. Tracks all subscription-requested
datatypes (tracked data). Maintains the State of the connection
at each layer, including the Actions to execute when new
packets are received.
This must be public in order to be accessible by generated filter
and update code.
Fields
linfo: LayerInfoActions and state from the perspective of L4 (TCP or UDP). Valid states are Payload or None.
cdata: ConnDataConnection five-tuple for filtering and determining directionality of future packets.
layers: [Layer; 1]Additional Layers that the L4 conn. should pass data to.
tracked: TSubscription data (for delivering)